@@ -3,4 +3,4 @@ from __future__ import absolute_import
 # flake8: noqa
 
 # import apis into api package
-from singlearity.api.default_api import DefaultApi
+from singlearity.api.ap_is_api import APIsApi
